# County Analysis
This package is meant to aid those intending to do any sort of analysis of cost of living, voting, or other county-level data, and to visualize it using choropleth maps.

This repository contains the data used in analysis, images produced, and the models to clean/merge the data, plot the data, and perform a basic prediction on the variables provided.

Install in the terminal with: pip install git+https://github.com/brycemartin52/county_package.git

Documentation is stored here:
#####

Data sources:
US Cost of Living Dataset (1877 Counties) - Data extracted from the Economic Policy Institute Family Budget Calculator: https://www.kaggle.com/datasets/asaniczka/us-cost-of-living-dataset-3171-counties/data

County Presidential Election Returns 2000-2020 - MIT Election Data and Science Lab, 2018, "County Presidential Election Returns 2000-2020": https://doi.org/10.7910/DVN/VOQCHQ='

Education Site used for data:
https://data.ers.usda.gov/reports.aspx?ID=17829
